############
Installation
############

*AFQ-Insight* requires Python >= 3.7. 

Installing the release version
------------------------------

The recommended way to install *AFQ-Insight* is from PyPI,

.. code-block:: console

    $ pip install afqinsight

This will install *AFQ-Insight* and all of its dependencies.

Installing the development version
----------------------------------

The development version is less stable but may include new features.
You can install the development version using ``pip``:

.. code-block:: console

    pip install git+https://github.com/richford/AFQ-Insight.git 

Alternatively, you can clone the source code from the `github repository
<https://github.com/richford/AFQ-Insight>`_:

.. code-block:: console

    $ git clone git@github.com:richford/AFQ-Insight.git
    $ cd AFQ-Insight
    $ pip install .

If you would like to contribute to *AFQ-Insight*, see the `contributing guidelines
<contributing.html>`_.

Next, go to the `user guide <user_guide.html>`_ or see the `example gallery
<auto_examples/index.html>`_ for further information on how to use *AFQ-Insight*.